.fabublox-dashboard {
    margin-top: 3rem;
}

.fabublox-dashboard .side-nav li {
    margin: 8px 0;
}

.fabublox-dashboard .side-nav li:first-child {
    margin-top: 0;
}

.fabublox-dashboard .side-nav li a {
    padding: 12px 18px;
    color: #333333;
    font-weight: 400;
    background-color: white;
    border: 2px solid #6a6a6a;
    cursor: pointer;
    text-align: center;
    border-radius: 4px;
    transition: all 0.2s ease;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.02);
}

.fabublox-dashboard .side-nav li.active a {
    color: #2c6fdb;
    border: 2px solid #2c6fdb;
    background-color: #f1f6ff;
    font-weight: 500;
    box-shadow: 0 2px 4px rgba(44, 111, 219, 0.1);
}

.fabublox-dashboard .side-nav li:not(.active):hover a {
    border-color: #bbbbbb;
    color: #444444;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
}

.fabublox-dashboard .tab-content {
    padding: 20px;
    border: 1px solid #e0e0e0;
    border-radius: 4px;
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.03);
}

.title {
    color: #333333;
    margin-bottom: 15px;
    font-weight: 500;
}

.info {
    color: #3e40fd;
}

.tab-title {
    margin-top: 0;
    margin-bottom: 0;
}

.text-danger {
    color: red;
}

.text-success {
    color: green;
}

.text-warning {
    color: orange;
}